<?php

namespace Litecms\SubscriberSaying\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\SubscriberSaying\Forms\SubscriberSaying as SubscriberSayingForm;
use Litecms\SubscriberSaying\Http\Requests\SubscriberSayingRequest;
use Litecms\SubscriberSaying\Interfaces\SubscriberSayingRepositoryInterface;
use Litecms\SubscriberSaying\Repositories\Eloquent\Filters\SubscriberSayingResourceFilter;
use Litecms\SubscriberSaying\Repositories\Eloquent\Presenters\SubscriberSayingListPresenter;

/**
 * Resource controller class for subscriber_saying.
 */
class SubscriberSayingResourceController extends BaseController
{

    /**
     * Initialize subscriber_saying resource controller.
     *
     *
     * @return null
     */
    public function __construct(SubscriberSayingRepositoryInterface $subscriber_saying)
    {
        parent::__construct();
        $this->form = SubscriberSayingForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.subscriber_saying.modules'), 'subscriber_saying', guard_url('subscriber_saying'));
        $this->repository = $subscriber_saying;
    }

    /**
     * Display a list of subscriber_saying.
     *
     * @return Response
     */
    public function index(SubscriberSayingRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(SubscriberSayingResourceFilter::class)
            ->setPresenter(SubscriberSayingListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('subscriber_saying::subscriber_saying.names'))
            ->view('subscriber_saying::subscriber_saying.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display subscriber_saying.
     *
     * @param Request $request
     * @param Model   $subscriber_saying
     *
     * @return Response
     */
    public function show(SubscriberSayingRequest $request, SubscriberSayingRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('subscriber_saying::subscriber_saying.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('subscriber_saying::subscriber_saying.show')
            ->output();
    }

    /**
     * Show the form for creating a new subscriber_saying.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(SubscriberSayingRequest $request, SubscriberSayingRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('subscriber_saying::subscriber_saying.name'))
            ->view('subscriber_saying::subscriber_saying.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new subscriber_saying.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SubscriberSayingRequest $request, SubscriberSayingRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('subscriber_saying::subscriber_saying.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('subscriber_saying/subscriber_saying/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/subscriber_saying/subscriber_saying'))
                ->redirect();
        }

    }

    /**
     * Show subscriber_saying for editing.
     *
     * @param Request $request
     * @param Model   $subscriber_saying
     *
     * @return Response
     */
    public function edit(SubscriberSayingRequest $request, SubscriberSayingRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('subscriber_saying::subscriber_saying.name'))
            ->view('subscriber_saying::subscriber_saying.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the subscriber_saying.
     *
     * @param Request $request
     * @param Model   $subscriber_saying
     *
     * @return Response
     */
    public function update(SubscriberSayingRequest $request, SubscriberSayingRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('subscriber_saying::subscriber_saying.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('subscriber_saying/subscriber_saying/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('subscriber_saying/subscriber_saying/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the subscriber_saying.
     *
     * @param Model   $subscriber_saying
     *
     * @return Response
     */
    public function destroy(SubscriberSayingRequest $request, SubscriberSayingRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('subscriber_saying::subscriber_saying.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('subscriber_saying/subscriber_saying/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('subscriber_saying/subscriber_saying/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
