<?php

namespace Litecms\SubscriberSaying\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\SubscriberSaying\Models\SubscriberSaying;

class SubscriberSayingPolicy
{

    /**
     * Determine if the given user can view the subscriber_saying.
     *
     * @param UserPolicyInterface $authUser
     * @param SubscriberSaying $subscriber_saying
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, SubscriberSaying $subscriber_saying)
    {
        if ($authUser->canDo('subscriber_saying.subscriber_saying.view') && $authUser->isAdmin()) {
            return true;
        }

        return $subscriber_saying->user_id == user_id() && $subscriber_saying->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subscriber_saying.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('subscriber_saying.subscriber_saying.create');
    }

    /**
     * Determine if the given user can update the given subscriber_saying.
     *
     * @param UserPolicyInterface $authUser
     * @param SubscriberSaying $subscriber_saying
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, SubscriberSaying $subscriber_saying)
    {
        if ($authUser->canDo('subscriber_saying.subscriber_saying.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $subscriber_saying->user_id == user_id() && $subscriber_saying->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subscriber_saying.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, SubscriberSaying $subscriber_saying)
    {
        return $subscriber_saying->user_id == user_id() && $subscriber_saying->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subscriber_saying.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, SubscriberSaying $subscriber_saying)
    {
        if ($authUser->canDo('subscriber_saying.subscriber_saying.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subscriber_saying.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, SubscriberSaying $subscriber_saying)
    {
        if ($authUser->canDo('subscriber_saying.subscriber_saying.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
