<?php

namespace Litecms\SubscriberSaying\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\SubscriberSaying\SubscriberSaying;

class SubscriberSayingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'subscriber_saying');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'subscriber_saying');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litecms\SubscriberSaying\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\SubscriberSaying\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\SubscriberSaying\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\SubscriberSaying\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.subscriber_saying', function($app)
        {
            return $this->app->make(SubscriberSaying::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind SubscriberSaying to repository
        $this->app->bind(
            'Litecms\SubscriberSaying\Interfaces\SubscriberSayingRepositoryInterface',
            \Litecms\SubscriberSaying\Repositories\Eloquent\SubscriberSayingRepository::class
        );
    }


    /**
     * Merges user's and subscriber_saying's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.subscriber_saying'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\SubscriberSaying\Commands\SubscriberSaying::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.subscriber_saying'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/subscriber_saying.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/subscriber_saying')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/subscriber_saying')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
